/* This file is part of PolyCalc.

   PolyCalc is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   any later version.

   PolyCalc is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PolyCalc.  If not, see <http://www.gnu.org/licenses/>.

   For more information about PolyCalc see project home
   <https://launchpad.net/polycalc>.

   Copyright 2012 PolyCalc development team */

/** \mainpage
    \image class-diagram-public-noQt.png
    \image class-diagram.png
  */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QGridLayout>
#include <QPushButton>
#include <QComboBox>
#include <QLabel>
#include <QProcess>
#include <QSettings>
#include <QList>
#include <QtXml>
#include <QSignalMapper>
#include <QtScript>
#include "pclineedit.h"
#include "pcscriptengine.h"
#include "pcappscript.h"
#include "pcstatusbar.h"
#include "pclayout.h"

namespace Ui {
class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT
    
public:
    explicit MainWindow(QString layoutName, QWidget *parent = 0);
    pcLayout *getLayout() { return(layout); }
    ~MainWindow();
    
private:
    Ui::MainWindow *ui;
    QSettings *settings;
    QSignalMapper *menuSignalMapper;
    QHash<QString, QString> layoutFiles;
    pcLayout *layout;
    void PopulateButtons(QString filename);
    void PopulateMenu();    
    void CreateLayoutMenuItems(QString path);
    void resizeEvent(QResizeEvent *event);
    void PopulateLayoutMenu(QDomNode &node, QMenu *parent);

private slots:
    void loadLayout(const QString &);
    void on_actionQuit_triggered();
    void on_actionAbout_triggered();
    void on_actionHelp_triggered();
    void on_actionCommand_Log_triggered();
    void on_actionClear_command_log_triggered();
    void on_actionLayout_help_triggered();
    void on_scriptEngineError(QString error);
    void on_actionSuggest_new_feature_triggered();
    void on_actionLook_for_more_triggered();
};

#endif // MAINWINDOW_H
