/* This file is part of PolyCalc.

   PolyCalc is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   any later version.

   PolyCalc is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PolyCalc.  If not, see <http://www.gnu.org/licenses/>.

   For more information about PolyCalc see project home
   <https://launchpad.net/polycalc>.

   Copyright 2012 PolyCalc development team */

#include <QString>
#include "pcbutton.h"

int pcButton::buttoncnt=0;

pcButton::pcButton(QWidget *parent) : QPushButton(parent)
{
    init();
}

pcButton::pcButton(QDomNode &node, pcAppScript *appScript, QWidget *parent) :
    QPushButton(parent)
{
    init();
    this->appScript = appScript;

    setText(node.toElement().attribute("caption",""));
    setToolTip(node.toElement().attribute("hint",""));

    insert  = node.toElement().attribute("insert",  QString());
    set     = node.toElement().attribute("set",     QString());
    append  = node.toElement().attribute("append",  QString());
    prepend = node.toElement().attribute("prepend", QString());
    send    = node.toElement().attribute("send") == "true";

    QString name = node.toElement().attribute("name", "");
    if (!name.isEmpty()) {
        setObjectName(name);
    }

    // should placed after setObjectName
    appScript->eval(buildInitCode(node));
}

void pcButton::updateLineEdit(QLineEdit *lineEdit)
{
    if (!insert.isNull())  { lineEdit->insert(insert); }
    if (!set.isNull())     { lineEdit->setText(set);   }
    if (!append.isNull())  { lineEdit->setText(lineEdit->text().append(append)); }
    if (!prepend.isNull()) { lineEdit->setText(lineEdit->text().prepend(prepend)); }
}

QString pcButton::buildInitCode(QDomNode &node)
{
    QString initCode = "";
    initCode +=
      objectName()+"=\""+node.toElement().attribute("caption","")+"\";\n\n";

    QString hooks[] = {"presend","postsend","preshow"};
    for (int i=0; i < 3; i++)
    {
        initCode += "function button"+QString::number(id)+hooks[i]+"() "+
                    "{ "+node.toElement().attribute(hooks[i],"")+" }\n\n";
    }
    return initCode;
}

pcButton *pcButton::Enter()
{
    pcButton *Enter = new pcButton();
    Enter->setObjectName("button_enter");
    Enter->send = true;
    Enter->appScript = NULL;
    return Enter;
}

void pcButton::init()
{
    setGeometry(0,0,45,25);
    setMinimumSize(45,25);
    setFocusPolicy(Qt::NoFocus);
    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);

    insert   = QString();
    set      = QString();
    append   = QString();
    prepend  = QString();
    send     = false;

    id = buttoncnt;
    setObjectName("button_"+QString::number(id));
    buttoncnt++;
}

void pcButton::callHook(QString name)
{
    if (appScript != NULL) {
        appScript->eval("button"+QString::number(id)+name+"();");
    }
}

void pcButton::updateCaption()
{
    if (appScript != NULL) {
        setText(appScript->eval(objectName()+";"));
    }
}

pcButton::~pcButton()
{
    buttoncnt--;
}
