/* This file is part of PolyCalc.

   PolyCalc is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   any later version.

   PolyCalc is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PolyCalc.  If not, see <http://www.gnu.org/licenses/>.

   For more information about PolyCalc see project home
   <https://launchpad.net/polycalc>.

   Copyright 2012 PolyCalc development team */

#include <QMessageBox>
#include <QFileDialog>
#include <QErrorMessage>
#include <QSettings>
#include "pcexecscriptengine.h"

pcExecScriptEngine::pcExecScriptEngine(QDomNode *node, QObject *parent) :
    pcScriptEngine(node, parent)
{
    QSettings settings("PolyCalc development team", "PolyCalc");
    engine = new QProcess(this);
    QString exe = node->toElement().attribute("command");
    if (!successfulStart(exe)) {
        QString userExe = settings.value(exe,exe).toString();
        if (!successfulStart(userExe)) {
            if (browseExeQuery(exe, userExe)) {
                if (!successfulStart(userExe)) {
                    canNotExecMsg(userExe);
                } else {
                    if (storeExeQuery()) {
                       settings.setValue(exe,userExe);
                    }
                }
            }
        }
    }
    eval(initCode);
}

bool pcExecScriptEngine::successfulStart(QString &exe)
{
    engine->start(exe, QIODevice::ReadWrite);
    return(engine->waitForStarted());
}

void pcExecScriptEngine::canNotExecMsg(QString &exe)
{
    QErrorMessage errorMessage;
    errorMessage.showMessage("Can not execute '"+exe+"'.");
    errorMessage.exec();
}

bool pcExecScriptEngine::storeExeQuery()
{
    QMessageBox msgBox;
    msgBox.setText("Executable opened.");
    msgBox.setInformativeText("Store executable path to settings?");
    msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
    msgBox.setDefaultButton(QMessageBox::Yes);
    return(msgBox.exec() == QMessageBox::Yes);
}

bool pcExecScriptEngine::browseExeQuery(QString &exe, QString &userExe)
{
    QMessageBox msgBox;
    msgBox.setText("Can not find executable '"+exe+"'.");
    msgBox.setInformativeText("Do you want to browse the executable?");
    msgBox.setStandardButtons(QMessageBox::Ok | QMessageBox::Cancel);
    msgBox.setDefaultButton(QMessageBox::Ok);
    if(msgBox.exec() == QMessageBox::Ok) {
        userExe = QFileDialog::getOpenFileName(0, "Open Macro", "", "* All files (*)");
        return(!userExe.isNull());
    } else {
        return(false);
    }
}

QString pcExecScriptEngine::eval(QString code)
{
    code += "\n";
    if (engine->write(code.toAscii()) == -1) {
        QString error = "Can not write standard input of external program: "+
                        engine->errorString();
        emit errorOccured(error);
    }
    engine->waitForBytesWritten(1000);
    engine->waitForReadyRead(1000);
    QString reply = QString(engine->readAllStandardOutput()).trimmed();
    emit changed();
    return reply;
}

pcExecScriptEngine::~pcExecScriptEngine()
{
    engine->closeWriteChannel();
    engine->closeReadChannel(QProcess::StandardOutput);
    engine->closeReadChannel(QProcess::StandardError);
    engine->close();
    delete engine;
}
