/* This file is part of PolyCalc.

   PolyCalc is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   any later version.

   PolyCalc is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PolyCalc.  If not, see <http://www.gnu.org/licenses/>.

   For more information about PolyCalc see project home
   <https://launchpad.net/polycalc>.

   Copyright 2012 PolyCalc development team */

#include "pcgrid.h"
#include "pclabel.h"

pcGrid::pcGrid(QDomNode &node,
               QString parentStyle,
               pcAppScript *appScript,
               QWidget *parent) :
    QGridLayout(parent)
{
    this->appScript = appScript;
    buttonSignalMapper = new QSignalMapper(this);
    connect(buttonSignalMapper, SIGNAL(mapped(QObject *)),
            this, SLOT(anyButtonClicked(QObject *)));

    int i = 0, j = 0;

    setMargin(0);
    setSpacing(node.toElement().attribute("spacing",0).toInt());

    for (QDomNode row = node.firstChild();
         !row.isNull();
         row = row.nextSibling(), j++)
    {
        i = 0;
        QString rowStyle = row.toElement().attribute("style",NULL);

        int rowStretch = row.toElement().attribute("stretch", "1").toInt();
        setRowStretch(j,rowStretch);

        for (QDomNode cell = row.firstChild();
             !cell.isNull();
             cell = cell.nextSibling(), i++)
        {
            int colStretch = cell.toElement().attribute("stretch", "1").toInt();
            setColumnStretch(i,colStretch);

            QString cellStyle = cell.toElement().attribute("style",NULL);
            QString style = (cellStyle != NULL) ? cellStyle :
                            (rowStyle != NULL)  ? rowStyle  :
                                                  parentStyle;

            if(cell.toElement().tagName() == "button")
            {
                pcButton *button = new pcButton(cell, appScript, parent);
                button->setStyleSheet(style);
                buttonSignalMapper->setMapping(button, (QObject *)button);
                connect(button, SIGNAL(clicked()),
                        buttonSignalMapper, SLOT (map()));
                addWidget(button, j, i);
            }
            if(cell.toElement().tagName() == "label")
            {
                pcLabel *label = new pcLabel(cell, appScript, parent);
                label->setStyleSheet(style);
                addWidget(label, j, i);
            }
            if(cell.toElement().tagName() == "grid")
            {
                pcGrid *childGridWidget = new pcGrid(cell, style, appScript, parent);
                connect(childGridWidget, SIGNAL(buttonClicked(QObject *)),
                        this,            SLOT(anyButtonClicked(QObject *)));
                addLayout(childGridWidget, j, i);
            }
        }
    }
}

pcGrid* pcGrid::buttonTable(QDomNode &node, pcAppScript *appScript, QWidget *parent)
{
    pcGrid* res;
    QDomNode firstChild = node.firstChild();
    if(firstChild.toElement().tagName() == "grid") {
        res = new pcGrid(firstChild,
                         firstChild.toElement().attribute("style",NULL),
                         appScript,
                         parent);
    }
    return(res);
}

void pcGrid::anyButtonClicked(QObject *button)
{
    emit buttonClicked(button);
}

pcGrid::~pcGrid()
{
    QLayoutItem* item;
    while ( (item = takeAt(0)) != NULL )
    {
        if (item->layout() != 0) delete (pcGrid*)item->layout();
        if (item->widget() != 0) delete item->widget();
    }
    delete buttonSignalMapper;
}
