/* This file is part of PolyCalc.

   PolyCalc is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   any later version.

   PolyCalc is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PolyCalc.  If not, see <http://www.gnu.org/licenses/>.

   For more information about PolyCalc see project home
   <https://launchpad.net/polycalc>.

   Copyright 2012 PolyCalc development team */

#ifndef PCLAYOUT_H
#define PCLAYOUT_H

#include <QObject>
#include "pclineedit.h"
#include "pcmenu.h"
#include "pcgrid.h"
#include "pcstatusbar.h"
#include "pcscriptengine.h"
#include "pcappscript.h"
#include "pcmacro.h"


/** PolyCalc Layout class.
    Builds from PolyCalc XML file. */
class pcLayout : public QObject
{
    Q_OBJECT

    pcLineEdit *lineEdit;
    pcStatusBar *statusbar;
    pcGrid *rootGrid;
    QList<pcMenu *> menus;

    pcButton *enter;
    pcMacro *macro;
    pcScriptEngine *scriptEngine;
    pcAppScript *stringPipeEngine;
    QString layouthelp;
    QHash<QString, QObject*> keysToButtons;
    QDomDocument *readDomFromFile(QString filename);
    void updateLabels(void);
public:
    explicit pcLayout(QString filename, QWidget *parent = 0);
    ~pcLayout();
    void showHelp();
    pcLineEdit *     getLineEdit()         { return(lineEdit); }
    pcStatusBar *    getStatusbar()        { return(statusbar); }
    pcGrid *         getRootGrid()         { return(rootGrid); }
    QList<pcMenu *>  getMenus()            { return(menus); }
    pcScriptEngine * getScriptEngine()     { return(scriptEngine); }
    pcAppScript *    getStringPipeEngine() { return(stringPipeEngine); }
    pcMacro *        getMacro()            { return(macro); }

signals:
    void output(QString text);
    
private slots:
    void anyButtonClicked(QObject *);
    void lineEdit_returnPressed(void);
    void lineEdit_useKeyPress(QString key, bool &inhibit);

public slots:
};

#endif // PCLAYOUT_H
