/* This file is part of PolyCalc.

   PolyCalc is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   any later version.

   PolyCalc is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PolyCalc.  If not, see <http://www.gnu.org/licenses/>.

   For more information about PolyCalc see project home
   <https://launchpad.net/polycalc>.

   Copyright 2012 PolyCalc development team */

#include <QKeyEvent>
#include <QLineEdit>
#include "pclineedit.h"

pcLineEdit::pcLineEdit(pcAppScript *appScript) : QComboBox()
{
    this->appScript = appScript;
    setEditable(true);
    setInsertPolicy(QComboBox::InsertAtCurrent);
    setStyleSheet("font-size: 12px;");
    insertItem(0,"");
    setCurrentIndex(0);
    lineEdit()->setAlignment(Qt::AlignRight);
}

void pcLineEdit::addNewText(QString text)
{
    int index;
    setItemText(currentIndex(), lineEdit()->text());
    while(index = findText(""), index != -1) removeItem(index);
    insertItem(0, text);
    setCurrentIndex(0);
}

void pcLineEdit::storeStatesToScript()
{
    appScript->eval("display = \""+QString(currentText())+"\";");
    appScript->eval("cursorpos = \""
                    +QString::number(lineEdit()->cursorPosition())+"\";");
    appScript->eval("beforeselection  = \""+
                    lineEdit()->text().left(
                        std::min(lineEdit()->cursorPosition(),
                                 lineEdit()->selectionStart()))+"\";");
    appScript->eval("beforecursor  = \""+
                    lineEdit()->text().left(
                        lineEdit()->cursorPosition())+"\";");
    appScript->eval("selected = \""+lineEdit()->selectedText()+"\";");
    appScript->eval("aftercursor  = \""+
                        lineEdit()->text().right(
                            lineEdit()->text().size() -
                            lineEdit()->cursorPosition())+"\";");
    appScript->eval("afterselection  = \""+
                        lineEdit()->text().right(
                            lineEdit()->text().size() -
                            std::max(lineEdit()->cursorPosition(),
                                     lineEdit()->selectionStart()))+"\";");
}

void pcLineEdit::keyPressEvent(QKeyEvent *event)
{
    bool inhibit = false;
    emit useKeyPress(event->text(), inhibit);
    if(!inhibit) {
      QComboBox::keyPressEvent(event);
    }
}
