/* This file is part of PolyCalc.

   PolyCalc is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   any later version.

   PolyCalc is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PolyCalc.  If not, see <http://www.gnu.org/licenses/>.

   For more information about PolyCalc see project home
   <https://launchpad.net/polycalc>.

   Copyright 2012 PolyCalc development team */

#ifndef PCLINEEDIT_H
#define PCLINEEDIT_H

#include <QComboBox>
#include "pcappscript.h"


/** Main text input item of Polycalc.
    Features:
    - command history
    ...
 */
class pcLineEdit : public QComboBox
{
    Q_OBJECT

    pcAppScript *appScript;

    /** Overloaded keyPressEvent, emits an unseKeyPress
        signal, and if the signal handled, inhibits the
        ancestor event handling. */
    void keyPressEvent(QKeyEvent *event);

public:
    explicit pcLineEdit(pcAppScript *appScript);
    void storeStatesToScript();
    void addNewText(QString text);
    
signals:
    /** Signal indicates key press. First parameter is the
        unicode text generated by the key, the second is a
        return parameter, if true, inhibites the ancestor
        event */
    void useKeyPress(QString keytext, bool &inhibit);

public slots:
};

#endif // PCLINEEDIT_H
