/* This file is part of PolyCalc.

   PolyCalc is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   any later version.

   PolyCalc is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PolyCalc.  If not, see <http://www.gnu.org/licenses/>.

   For more information about PolyCalc see project home
   <https://launchpad.net/polycalc>.

   Copyright 2012 PolyCalc development team */

#include <QMessageBox>
#include <QFileDialog>
#include "pcmacro.h"
#include "pcbutton.h"

pcMacro::pcMacro(QWidget *parent) :
    QMenu(parent)
{
    widget = parent;
    recordMacro = false;
    setTitle("Macro");
    startAction = addAction("Start Record &Macro");
    stopAction  = addAction("Stop &Record Macro");
    playAction  = addAction("&Play Macro");
    loadAction  = addAction("L&oad Macro");
    saveAction  = addAction("&Save Macro");

    stopAction->setEnabled(false);
    startAction->setEnabled(true);
    loadAction->setEnabled(true);
    saveAction->setEnabled(false);
    playAction->setEnabled(false);

    stopAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_T));
    startAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_R));
    loadAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_O));
    saveAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_S));
    playAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_P));

    connect(startAction, SIGNAL(triggered()), this, SLOT(Start_triggered()));
    connect(stopAction,  SIGNAL(triggered()), this, SLOT(Stop_triggered()));
    connect(playAction,  SIGNAL(triggered()), this, SLOT(Play_triggered()));
    connect(loadAction,  SIGNAL(triggered()), this, SLOT(Load_triggered()));
    connect(saveAction,  SIGNAL(triggered()), this, SLOT(Save_triggered()));
}

pcMacro::~pcMacro()
{
    delete startAction;
    delete stopAction;
    delete playAction;
    delete loadAction;
    delete saveAction;
}

void pcMacro::play()
{
    for (int i = 0; i < macroItems.size(); ++i) {
        pcButton *target = widget->findChild<pcButton *>(macroItems.at(i));
        emit sendButtonClick((QObject *)target);
    }
}

void pcMacro::load(QString fileName)
{
    if (fileName.isEmpty())
        return;
    else {
        QFile file(fileName);
        if (!file.open(QIODevice::ReadOnly)) {
            QMessageBox::information(this, "Unable to open file",
                file.errorString());
            return;
        }
        QDataStream in(&file);
        in.setVersion(QDataStream::Qt_4_5);
        macroItems.clear();
        in >> macroItems;
    }
    saveAction->setEnabled(true);
    playAction->setEnabled(true);
}

void pcMacro::addMacroItem(QString text)
{
    if(recordMacro) macroItems.append(text);
}

void pcMacro::Start_triggered()
{
    macroItems.clear();
    recordMacro = true;
    stopAction->setEnabled(true);
    startAction->setEnabled(false);
    loadAction->setEnabled(false);
    saveAction->setEnabled(false);
    playAction->setEnabled(false);
}

void pcMacro::Stop_triggered()
{
    recordMacro = false;
    stopAction->setEnabled(false);
    startAction->setEnabled(true);
    loadAction->setEnabled(true);
    saveAction->setEnabled(true);
    playAction->setEnabled(true);
}

void pcMacro::Play_triggered()
{
    play();
}

void pcMacro::Load_triggered()
{
    QString fileName = QFileDialog::getOpenFileName(this,
        "Open Macro", "", "*.pcm Polycalc Macro (*.pcm);;* All files (*)");
    load(fileName);
}

void pcMacro::Save_triggered()
{
    QString fileName = QFileDialog::getSaveFileName(this,
        "Save macro", "", "*.pcm Polycalc Macro (*.pcm);;* All files (*)");

    if (fileName.isEmpty())
        return;
    else {
        QFile file(fileName);
        if (!file.open(QIODevice::WriteOnly)) {
            QMessageBox::information(this, "Unable to open file",
                file.errorString());
            return;
        }
        QDataStream out(&file);
        out.setVersion(QDataStream::Qt_4_5);
        out << macroItems;
    }
}
