/* This file is part of PolyCalc.

   PolyCalc is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   any later version.

   PolyCalc is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PolyCalc.  If not, see <http://www.gnu.org/licenses/>.

   For more information about PolyCalc see project home
   <https://launchpad.net/polycalc>.

   Copyright 2012 PolyCalc development team */

#include <QErrorMessage>
#include "pcscriptengine.h"
#include "pcqscriptengine.h"
#include "pcexecscriptengine.h"

pcScriptEngine::pcScriptEngine(QDomNode *node, QObject *parent) :
    QObject(parent)
{
    initCode = "";
    if (!node->isNull())
    {
        for (QDomNode scriptElement = node->firstChild();
             !scriptElement.isNull();
             scriptElement = scriptElement.nextSibling())
        {
             if (scriptElement.toElement().tagName() == "init")
             {
                 initCode = scriptElement.toElement().text();
             }
        }
    }
}

pcScriptEngine* pcScriptEngine::create(QDomNode *node, QObject *parent)
{
    pcScriptEngine *scriptEngine;
    if (node->toElement().attribute("type") == "external")
    {
        scriptEngine = new pcExecScriptEngine(node, parent);
    }
    else
    if (node->toElement().attribute("type") == "QtScript")
    {
        scriptEngine = new pcQScriptEngine(node, parent);
    }
    else
    {
        QErrorMessage errorMessage;
        errorMessage.showMessage("Not supported engine '"
                                 +node->toElement().attribute("type")
                                 +"'. PolyCalc falls back to QScript.");
        errorMessage.exec();
        scriptEngine = new pcQScriptEngine(node, parent);
    }
    return(scriptEngine);
}
