/* This file is part of PolyCalc.

   PolyCalc is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   any later version.

   PolyCalc is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PolyCalc.  If not, see <http://www.gnu.org/licenses/>.

   For more information about PolyCalc see project home
   <https://launchpad.net/polycalc>.

   Copyright 2012 PolyCalc development team */

#include <QDesktopServices>
#include <QNetworkAccessManager>
#include <QNetworkRequest>
#include <QNetworkReply>
#include <QDebug>
#include <QMessageBox>
#include <QEventLoop>
#include "pcupdate.h"
#include "pcconfig.h"

pcUpdate::pcUpdate(QWidget *parent) :
    QAction(parent)
{
    setText("Check for updates online");
    connect(this, SIGNAL(triggered()),
            this, SLOT(onTriggered()));
}

void pcUpdate::onTriggered()
{
    QNetworkAccessManager manager;
    QString url=pcConfig::versionUrl;
    QNetworkReply *reply = manager.get(QNetworkRequest(url));
    QEventLoop loop;
    connect(reply, SIGNAL(finished()), &loop, SLOT(quit()));
    loop.exec();

    if (reply->error() != QNetworkReply::NoError)
    {
        qDebug() << "Error in" << reply->url() << ":" << reply->errorString();
        QMessageBox::information(
            0,
            tr("PolyCalc message"),
            tr("Could not connect to server."));
        return;
    }
    QString text = reply->readAll();

    if (text == pcConfig::version)
    {
        QMessageBox::information
        (
            0,
            tr("Check for Updates Online"),
            tr("There are no updates available.") );
        } else{
            qDebug() << "Received data:" << text;
            switch( QMessageBox::question(
                0,
                tr("Check for Updates Online"),
                tr("A new version of PolyCalc is available. Would you like to download it?"),
                QMessageBox::Yes |
                QMessageBox::No |
                QMessageBox::Cancel,
                QMessageBox::Cancel ) )
        {
            case QMessageBox::Yes:
                qDebug( "yes" );
                QDesktopServices::openUrl(QUrl(pcConfig::downloadUrl));
            break;
            case QMessageBox::No:
                qDebug( "no" );
            break;
            case QMessageBox::Cancel:
                qDebug( "cancel" );
            break;
            default:
                qDebug( "close" );
            break;
        } // switch internal
    } // else
}
